/**
 * ieus_udc-lib header file
 */

#ifndef __IEUS_UDC_LIB_H__
#define __IEUS_UDC_LIB_H__

#include <asm/types.h>
#include "ieus_udc_ioctl.h"


typedef enum {
    IEUS_UDC_OK = 0,
    IEUS_UDC_ERR = -1,
    IEUS_UDC_ABORTED = -2,
} IEUS_UDC_RESULT;

typedef void *IEUS_UDC_CONTEXT;

IEUS_UDC_RESULT ieus_udc_DefaultRequestHandler( IEUS_UDC_CONTEXT context, PIOCTL_EP0 pIOCTL_ep0, PEP0STATEMACHINE pStateMachine );

/**
 * Defines the callbacks in the user-defined code for handling USB device functionality.
 * 
 * usrHandleRequest should generally call back to ieus_udc_DefaultRequestHandler for handling of 
 * standard requests.
 * 
 * Currently only a single configuration is supported (e.g. 1==wNumConfigurations).
 */
typedef struct {
    PDEVICE_DESCRIPTOR  pDeviceDescriptor;
    PDESC_GLOB          pConfigurationGlobArray;
    __u32               wGlobArraySize;
    PHID_REPORT_GLOB    pHidReportGlobArray;
    __u32               wHidReportSize;
    IEUS_UDC_RESULT (*usrHandleRequest)( IEUS_UDC_CONTEXT context, PIOCTL_EP0 pIOCTL_ep0, PEP0STATEMACHINE pStateMachine );
} IEUS_UDC_CLIENT, *PIEUS_UDC_CLIENT;

/**
 * Initializes library.
 * Opens device, initializes context and starts a thread for Endpoint0 execution.
 * 
 * pDeviceName may be NULL.
 */
IEUS_UDC_RESULT ieus_udc_InitializeLibraryContext(IEUS_UDC_CONTEXT *pContext, PIEUS_UDC_CLIENT pClientInfo, char *pDeviceName);

/**
 * Gracefully closes the usb library by aborting any oustanding threads/requests and closing the underlying device
 */
void ieus_udc_DestroyLibraryContext(IEUS_UDC_CONTEXT context);

/**
 * This function is reserved for internal / debugging purposes only.
 * It returns the handle of the actual device driver in use by the library.
 */
int ieus_udc_GetDeviceHandle(IEUS_UDC_CONTEXT context);

IEUS_UDC_RESULT ieus_udc_stallEndpoint(IEUS_UDC_CONTEXT context, __u8 bEndpoint);
IEUS_UDC_RESULT ieus_udc_GetDriverState(IEUS_UDC_CONTEXT context, PIEUS_UDC_STATE pState);
IEUS_UDC_RESULT ieus_udc_SendEP0Data( IEUS_UDC_CONTEXT context, __u16 wLength, void *pData );
IEUS_UDC_RESULT ieus_udc_SendEPxData( IEUS_UDC_CONTEXT context, __u8 bEndpoint, __u16 wLength, void *pData );

#endif


