// **********************************************************************
//
// lcd_output_manager.h: Jefferson LCD Output Manager
//
// This module contains data type and function definitions that constitute 
// public interface to the the LCD Output Manager
//

#ifndef __LCD_OUTPUT_MANAGER_H
#define __LCD_OUTPUT_MANAGER_H

#define MWINCLUDECOLORS
#include <nano-X.h>

#include "ie_types.h"
#include "main.h"

typedef GR_RECT       o_rect_t;
typedef GR_GC_ID      o_gc_t;
typedef GR_POINT      o_point_t;
typedef GR_WINDOW_ID  o_window_id_t;
typedef GR_COLOR      o_color_t;
typedef GR_IMAGE_ID   o_imageid_t;

// Constants
// default rectangle for a window
static const int def_x         = 0;
static const int def_y         = 0;
static const int max_xres      = 320;
static const int max_yres      = 240;

// default colors 
static const o_color_t def_bg_color  = WHITE;
static const o_color_t def_fg_color  = BLACK;

// Function prototypes
extern BOOL lom_start_graphics();
extern void lom_stop_graphics();
extern BOOL lom_draw_line(o_point_t *point_a, o_point_t *point_b, INT16U width, o_color_t line_color);
extern BOOL lom_get_lcd_info(INT16U *xWidth, INT16U *yWidth, INT8U *colorCode, INT8U *bpp);
extern BOOL lom_clear_bitmap(INT8U bitmapId);
extern BOOL lom_clear_window(o_window_id_t window_id, o_color_t bg_color);
extern BOOL lom_create_bitmap(INT8U bitmapId, INT8U *bitmapBuff, INT32U bitmapBytesize);
extern BOOL lom_display_bitmap(INT8U  bitmapId, INT16U bmX, INT16U bmY,
                               INT8U  screenId, INT16U scX, INT16U scY,
                               INT16U xWidth,   INT16U yWidth,
                               INT8U  stretch,  INT8U  overlay);
extern BOOL lom_set_contrast(INT8U contrastValue);

// **********************************************************************
// Accessors
extern o_window_id_t lom_get_main_window_id();

// **********************************************************************
// These functions are used to save/restore area of screen as part of inking region
// They are specifically used for the inking-with-timeout for SetInkingRegion message
extern void lom_copy_to_offscreen_window(INT16U scX,   INT16U scY,
                                         INT16U xWidth,INT16U yWidth,
                                         o_window_id_t *window_id);
extern void lom_remove_offscreen_window(o_window_id_t window_id);
extern void lom_display_offscreen_window(o_window_id_t window_id,
                                         INT16U scX,   INT16U scY,
                                         INT16U xWidth,INT16U yWidth);


#endif
